"""    
  This file is a part of TkDraw
  
  Copyright (C) 2011  Rujia Liu

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  
  USA
"""

import sys
from Tkinter import *

def onMouseDown(event):
  statusText.set("%d,%d" % (event.x, event.y))

def onRightMouseDown(event):
  global scale, dx, dy
  scale = 1
  dx = dy = 0
  f = open(sys.argv[1], 'r')
  solo = False
  inblock = True
  draw("CLEAR")
  for line in f.readlines():
    line = line.strip()
    if line == '-s':
      if not solo:
        solo = True # start to draw a solo block
        draw("CLEAR")
      else:
        break # end of solo
    elif line == '-[':
      if inblock:
        draw("CLEAR") # clear previously drawn content
      inblock = True
    elif line == '-]':
      inblock = False
    else:
      if inblock:
        draw(line) # draw if we're inside a block
  f.close()

def buildGUI():
  global canvas, statusText

  canvas = Canvas(width=800, height=600, background='#ffffff')
  canvas.bind("<Button-1>", onMouseDown)
  canvas.bind("<Button-3>", onRightMouseDown)
  canvas.pack()

  statusText = StringVar()
  status = Label(root, textvariable=statusText, bd=1, relief=SUNKEN, anchor=W)
  status.pack(side=BOTTOM, fill=X)

def draw(command):
  global scale, dx, dy
  cmd = command.split()
  if cmd[0] == "TRANSLATE":
    dx = float(cmd[1])
    dy = float(cmd[2])
  if cmd[0] == "SCALE":
    scale = float(cmd[1])
  if cmd[0] == 'LINE':
    x1 = (float(cmd[1]) + dx) * scale
    y1 = (float(cmd[2]) + dy) * scale
    x2 = (float(cmd[3]) + dx) * scale
    y2 = (float(cmd[4]) + dy) * scale
    canvas.create_line(x1, y1, x2, y2)
  if cmd[0] == 'CIRCLE':
    x = (float(cmd[1]) + dx) * scale
    y = (float(cmd[2]) + dy) * scale
    r = float(cmd[3]) * scale
    canvas.create_oval(x-r, y-r, x+r, y+r)
  if cmd[0] == 'CLEAR':
    all = canvas.find_all()
    for item in all:
      canvas.delete(item)

root = Tk()
buildGUI()
root.mainloop()
